about summary refs log tree commit diff
path: root/src/librustc_const_eval
diff options
context:
space:
mode:
authorNicholas Nethercote <nnethercote@mozilla.com>2016-11-04 15:04:16 +1100
committerNicholas Nethercote <nnethercote@mozilla.com>2016-11-04 16:11:41 +1100
commit43452a36efae22492ffef157ce44f05346bde1b0 (patch)
treef06f6637303132a548c8aa029f42eed27ffff8b3 /src/librustc_const_eval
parent9366ba31668af3575ecadb3b35d2b67e138c3605 (diff)
Shrink `Expr_::ExprStruct`.
On 64-bit platforms this reduces the size of `Expr_` from  64 bytes to
56 bytes, and reduces the size of `Expr` from 88 bytes to 80 bytes.
Diffstat (limited to 'src/librustc_const_eval')
-rw-r--r--src/librustc_const_eval/eval.rs2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/librustc_const_eval/eval.rs b/src/librustc_const_eval/eval.rs
index c02cca0da72..ad9e718617a 100644
--- a/src/librustc_const_eval/eval.rs
+++ b/src/librustc_const_eval/eval.rs
@@ -314,7 +314,7 @@ pub fn const_expr_to_pat<'a, 'tcx>(tcx: TyCtxt<'a, 'tcx, 'tcx>,
                           },
                       }))
                       .collect::<Result<_, _>>()?;
-            PatKind::Struct(path.clone(), field_pats, false)
+            PatKind::Struct((**path).clone(), field_pats, false)
         }
 
         hir::ExprArray(ref exprs) => {